(v0.2.9)=
### 0.2.9 {small}`2017-10-25`

#### Initial release of the new trajectory inference method [PAGA](https://github.com/theislab/paga)

- {func}`~scanpy.tl.paga` computes an abstracted, coarse-grained (PAGA) graph of the neighborhood graph {smaller}`A Wolf`
- {func}`~scanpy.pl.paga_compare` plot this graph next an embedding {smaller}`A Wolf`
- {func}`~scanpy.pl.paga_path` plots a heatmap through a node sequence in the PAGA graph {smaller}`A Wolf`
